'
'  Skipfix.vbs script (7/19/2008)
'  by Tundra-
'
'  purpose: to adjust edl times so that Sagetv media player commercial skip
'    times correlate with calculated times from comskip or Showanalyzer when
'    actual media file duration does not match Sagetv scheduled duration
'
'  usage example:  cscript skipfix.vbs "\\pvr\recordings\mediafilename"
'    In addition to adjusting the edl numbers, it will rename the old edl to
'    edl_orig and also make an edl_log file.
'
'  note, this uses the open source project 'MediaInfo' to extract the media file's info.
'    Download the command line version of MediaInfo from 
'    http://mediainfo.sourceforge.net/en/Download
'    Place script within mediainfo folder or adjust mediainfo path below
'
'  also note, this uses the media file creation/lastmodified timestamps to
'    estimate the intended Sagetv scheduled duration.  If your media file is
'    modified after it is recorded and those timestamps are changed, this script
'    would then likely completely hose the edl times
'

Sub echo(str)
  wscript.echo str : flog.writeline str
End Sub

Set fs = CreateObject("Scripting.FileSystemObject")
Set oShell = wscript.CreateObject("wscript.shell")

'--- get file name and do some basic error checking
If wscript.arguments.count <> 1 Then wscript.echo "Error: specify media file" : wscript.quit
f = wscript.arguments(0)
If Not fs.fileexists(f) Then wscript.echo "Error: media file does not exist" : wscript.quit
base = Left(f, Len(f) - Len(fs.GetFileName(f))) & fs.GetBaseName(f)
If fs.fileexists(base & ".edl_orig") Then wscript.echo "Error: edl already modified" : wscript.quit

'--- start logfile
Set flog = fs.CreateTextFile(base & ".edl_log", True)

'--- run mediainfo to get media file info...only fields needed are returned to make parsing easy
Set oExec = oShell.Exec("mediainfo.exe --Inform=General;%Duration%|%File_Created_Date%|%File_Modified_Date% " & "" & f & "")

all = split(oExec.stdout.readall,"|")
md  = all(0)/1000				'--- mediainfo duration
s   = mid(all(1),5,23)				'--- file create timestamp
e   = mid(all(2),5,23)				'--- file last modified timestamp
ms  = mid(all(2),24,4) - mid(all(1),24,4)	'--- timestamp fractional seconds...overkill...but...
td  = DateDiff("s", left(s,19), left(e,19))+ms	'--- timestamp based duration
sd  = round(td/60)*60				'--- est sagetv duration (timestamp duration rounded to nearest minute)
r   = sd/md					'--- the magic ratio used to adjust the edl

echo "File creation:      " & s
echo "File last modified: " & e
echo "Timestamp duration: " & td
echo ""
echo "Sagetv duration(?): " & sd
echo "MediaInfo duration: " & md
echo "Discrepancy (secs): " & csng(md - sd)
echo ""
echo "Adjustment ratio:   " & r
echo ""

'--- rename the original edl, open it, and create the new edl file
fs.MoveFile base & ".edl", base & ".edl_orig"
Set fo = fs.OpenTextFile(base & ".edl_orig", 1, 0)
Set f2 = fs.CreateTextFile(base & ".edl", True)
t = Chr(9)
While Not fo.AtEndOfStream
  a = fo.readline
  b = Split(a, Chr(9)) : If UBound(b) = 0 Then b = Split(a, " ")
  echo b(0) & t & b(1) & t & b(2) & t & "|" & t & Round(b(0) * r, 3) & t & Round(b(1) * r, 3) & t & b(2)
  f2.write (Round(b(0) * r, 3) & t & Round(b(1) * r, 3) & t & b(2)) & chr(10)
Wend

fo.Close : f2.Close : flog.Close
Set oShell = Nothing
Set fs = Nothing